==> designate_2015.1~rc1.orig.tar.gz: designate-2015.1.0rc1/designate/api/versions.py <==
# Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
#
# Author: Kiall Mac Innes <kiall@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
import flask
from oslo.config import cfg


def factory(global_config, **local_conf):
    app = flask.Flask('designate.api.versions')

    versions = []

    base = cfg.CONF['service:api'].api_base_uri.rstrip('/')

    def _version(version, status):
        if version.isdigit():
            versions.append({
                'id': 'v%s' % version,
                'status': status,
                'links': [{
                    'href': base + '/v' + version,
                    'rel': 'self'
                }]
            })
        else:
            versions.append({
                'id': '%s' % version,
                'status': status,
                'links': [{
                    'href': base + '/' + version,
                    'rel': 'self'
                }]
            })

    if cfg.CONF['service:api'].enable_api_v1:
        _version('1', 'DEPRECATED')

    if cfg.CONF['service:api'].enable_api_v2:
        _version('2', 'CURRENT')

    @app.route('/', methods=['GET'])
    def version_list():

        return flask.jsonify({
            "versions": {
                "values": versions
            }
        })

    return app

==> designate-2015.1.0b3.tar.gz: designate-2015.1.0b3/designate/api/versions.py <==
# Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
#
# Author: Kiall Mac Innes <kiall@hp.com>
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
import flask
from oslo.config import cfg


def factory(global_config, **local_conf):
    app = flask.Flask('designate.api.versions')

    versions = []

    base = cfg.CONF['service:api'].api_base_uri.rstrip('/')

    def _version(version, status):
        if version.isdigit():
            versions.append({
                'id': 'v%s' % version,
                'status': status,
                'links': [{
                    'href': base + '/v' + version,
                    'rel': 'self'
                }]
            })
        else:
            versions.append({
                'id': '%s' % version,
                'status': status,
                'links': [{
                    'href': base + '/' + version,
                    'rel': 'self'
                }]
            })

    if cfg.CONF['service:api'].enable_api_v1:
        _version('1', 'CURRENT')

    if cfg.CONF['service:api'].enable_api_v2:
        _version('2', 'EXPERIMENTAL')

    @app.route('/', methods=['GET'])
    def version_list():

        return flask.jsonify({
            "versions": {
                "values": versions
            }
        })

    return app
